@@ -31,9 +31,16 @@ class RmqPublisher(messages.BasePublisherWithReplyQueue):
     DEFAULT_EXCHANGE_PARAMS = EXCHANGE_PROPERTIES
 
     async def rpc_send(self, recipient_id, msg):
+        routing_key = f'{defaults.RPC_TOPIC}.{recipient_id}'
+        _LOGGER.debug(
+            'Sending RPC with routing key %r to RMQ queue %r: %r',
+            routing_key,
+            self._reply_queue.name,
+            msg,
+        )
         message = aio_pika.Message(body=self._encode(msg), reply_to=self._reply_queue.name)
         published, response_future = await self.publish_expect_response(
-            message, routing_key=f'{defaults.RPC_TOPIC}.{recipient_id}', mandatory=True
+            message, routing_key=routing_key, mandatory=True
         )
         assert published, 'The message was not published to the exchanges'
         return response_future
@@ -45,6 +52,12 @@ class RmqPublisher(messages.BasePublisherWithReplyQueue):
             subject=subject,
             correlation_id=correlation_id,
         )
+        _LOGGER.debug(
+            'Sending broadcast with routing key %r to RMQ via exchange %r: %r',
+            defaults.BROADCAST_TOPIC,
+            self._exchange_name,
+            message_dict,
+        )
         message = aio_pika.Message(
             body=self._encode(message_dict),
             delivery_mode=aio_pika.DeliveryMode.NOT_PERSISTENT,
@@ -188,9 +201,9 @@ class RmqSubscriber:
         """
         :param subscriber: the subscriber function or coroutine that will get the RPC message
         :param message: the RMQ message
-        :type message: :class:`aio_pika.message.IncomingMessage`
+        :type message: :class:`aio_pika.IncomingMessage`
         """
-        with message.process(ignore_processed=True):
+        async with message.process(ignore_processed=True):
             # Tell the sender that we've dealt with it
             message.ack()
             msg = self._decode(message.body)
@@ -209,7 +222,7 @@ class RmqSubscriber:
                     await self._send_response(message.reply_to, message.correlation_id, utils.result_response(result))
 
     async def _on_broadcast(self, message):
-        with message.process():
+        async with message.process():
             msg = self._decode(message.body)
             for receiver in self._broadcast_subscribers.values():
                 try:
